@@ -6,9 +6,6 @@ import pandas as pd
 from lifelines.plotting import plot_dataframes
 from lifelines.utils import survival_table_from_events, basis, inv_normal_cdf, quadrature
 
-
-import pdb
-
 class NelsonAalenFitter(object):
     """
     Class for fitting the Nelson-Aalen estimate for the cumulative hazard. 
@@ -165,7 +162,7 @@ def _additive_estimate(events, timeline, _additive_f, _additive_var):
     deaths = events['observed']
     population = N - events['removed'].cumsum().shift(1).fillna(0)
     estimate_ = np.cumsum(_additive_f(population,deaths)) 
-    var_ = _additive_var(population, deaths)
+    var_ = np.cumsum(_additive_var(population, deaths))
 
     estimate_ = estimate_.reindex(timeline, method='pad').fillna(0)
     var_ = var_.reindex(timeline, method='pad')
